﻿using System;
using DataCash;

namespace EPiServer.Business.Commerce.Payment.DataCash
{
    public partial class DataCashLandingPage : System.Web.UI.Page
    {
        /// <summary>
        /// Handles the Load event of the Page control.
        /// </summary>
        /// <param name="sender">The source of the event.</param>
        /// <param name="e">The <see cref="System.EventArgs"/> instance containing the event data.</param>
        protected void Page_Load(object sender, EventArgs e)
        {
            DisplayCardDetail(GetInputCardDetail());
        }

        /// <summary>
        /// Get input card detail.
        /// </summary>
        /// <returns>Document contains input card detail.</returns>
        private Document GetInputCardDetail()
        {
            var gateway = new DataCashPaymentGateway();
            var requestDoc = new Document(gateway.DataCashConfiguration);
            requestDoc.set("Request.Authentication.client", gateway.UserId);
            requestDoc.set("Request.Authentication.password", gateway.Password);
            requestDoc.set("Request.Transaction.HistoricTxn.method", "query");
            requestDoc.set("Request.Transaction.HistoricTxn.reference", Session[DataCashPaymentGateway.ReferenceSessionKey] as string);
            return DataCashPaymentGateway.SendTransaction(requestDoc);
        }

        /// <summary>
        /// Display card detail.
        /// </summary>
        /// <param name="cardDetail">Input card detail.</param>
        private void DisplayCardDetail(Document cardDetail)
        {
            cardType.Text = cardDetail.get("Response.HpsTxn.card_scheme");
            cardNumber.Text = cardDetail.get("Response.HpsTxn.pan");
            var expiDate = cardDetail.get("Response.HpsTxn.expirydate");
            if (!string.IsNullOrEmpty(expiDate) && expiDate.Length >= 3)
            {
                expirateDate.Text = string.Format("{0}/{1}", expiDate.Substring(0, 2), expiDate.Substring(2));
            }
        }
    }
}
